==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-registry/nifi-registry-core/nifi-registry-web-api/src/main/java/org/apache/nifi/registry/web/security/authorization/HttpMethodAuthorizationRules.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.web.security.authorization;

import org.apache.nifi.registry.security.authorization.RequestAction;
import org.springframework.http.HttpMethod;

public interface HttpMethodAuthorizationRules {

    default boolean requiresAuthorization(HttpMethod httpMethod) {
        return true;
    }

    default RequestAction mapHttpMethodToAction(HttpMethod httpMethod) {

        switch (httpMethod) {
            case TRACE:
            case OPTIONS:
            case HEAD:
            case GET:
                return RequestAction.READ;
            case POST:
            case PUT:
            case PATCH:
                return RequestAction.WRITE;
            case DELETE:
                return RequestAction.DELETE;
            default:
                throw new IllegalArgumentException("Unknown http method: " + httpMethod);
        }

    }

}

==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-registry/nifi-registry-core/nifi-registry-web-api/src/main/java/org/apache/nifi/registry/web/security/authorization/HttpMethodAuthorizationRules.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.web.security.authorization;

import org.apache.nifi.registry.security.authorization.RequestAction;
import org.springframework.http.HttpMethod;

public interface HttpMethodAuthorizationRules {

    default boolean requiresAuthorization(HttpMethod httpMethod) {
        return true;
    }

    default RequestAction mapHttpMethodToAction(HttpMethod httpMethod) {

        switch (httpMethod.name()) {
            case "TRACE":
            case "OPTIONS":
            case "HEAD":
            case "GET":
                return RequestAction.READ;
            case "POST":
            case "PUT":
            case "PATCH":
                return RequestAction.WRITE;
            case "DELETE":
                return RequestAction.DELETE;
            default:
                throw new IllegalArgumentException("Unknown http method: " + httpMethod);
        }

    }

}
